/*
 * display.c - handling the display
 *
 * author: hackbard@hackdaworld.org
 *
 */

#include "display.h"
#include "system.h"
#include "default_logo.h"
#include "uart.h"

/*
 * functions
 */

void display_clear_screen(void) {

	u32 cnt;

	DISPLAY_SET_PAGE_ADDR(0);
	DISPLAY_SET_C_ADDR(0);

	for(cnt=0;cnt<DISPLAY_RAM_CONTENT;cnt++)
		DISPLAY_DATA=0x00;
}

void display_init(void) {

	DISPLAY_EXIT_POWER_SAVE;

	DISPLAY_SOFT_RESET;
	pause(0xffffff);

	DISPLAY_START_OSCILLATOR;

	DISPLAY_SET_REGULATOR(7);

	DISPLAY_SET_CONTRAST(0x38);

	DISPLAY_SET_CONV_FACTOR(0x01);

	DISPLAY_SET_UW_CORNER(0x1c,0x0a);
	DISPLAY_SET_LW_CORNER(0x75,0x81);

	DISPLAY_SET_PWM_FRC(0,0);

	DISPLAY_SET_WHITE(0,0,0,0);
	DISPLAY_SET_LGRAY(4,4,4,4);
	DISPLAY_SET_DGRAY(6,6,6,6);
	DISPLAY_SET_BLACK(9,9,9,9);

	DISPLAY_SET_SEGMENT_REMAP_00H;
	DISPLAY_SET_COM_ODIR_REMAPPED;

	DISPLAY_SET_POWER(DISPLAY_REGULATOR|DISPLAY_OPAMP);
	pause(0xffffff);
	DISPLAY_SET_POWER(DISPLAY_V_BOOST|DISPLAY_REGULATOR|DISPLAY_OPAMP);
	
	DISPLAY_RAM_CONTENTS_ON;

	DISPLAY_NORMAL;

	display_clear_screen();

	DISPLAY_SET_ON;
}

void display_load_logo(u8 *src) {

	u32 cnt;
	u8 *s;

	s=src;
	if(s==0)
		s=default_logo;

	DISPLAY_SET_PAGE_ADDR(0);
	DISPLAY_SET_C_ADDR(0);

	for(cnt=0;cnt<DISPLAY_RAM_CONTENT;cnt++)
		DISPLAY_DATA=s[cnt];
}

void display_bl_init(void) {

	IODIR0|=(1<<4);
	IOSET0=(1<<4);	// off by default
}

void display_bl_toggle(void) {

	if(IOPIN0&(1<<4))
		IOCLR0=(1<<4);
	else
		IOSET0=(1<<4);
}

void display_bl_on(void) {

	IOCLR0=(1<<4);
}

void display_bl_off(void) {

	IOSET0=(1<<4);
}

